@@ -13,11 +13,11 @@ sample_index=0
 sample_smoothing=10 #value_smoothing at 1. level
 value_smoothing=10 #value_smoothing at 2. level
 derivation=5 #shift in derivation
-Ysize=120
-Yscale=3
-arrXscale=[1, 4, 6]
+Ysize=120 #default value Y scale in px
+Yscale=3 #default value Y stretching
+arrXscale=[1, 4, 6] #scaling steps X accis
 arrXscaleLen=3
-Xscale=1
+Xscale=1 #default value X scale in arraXscale index
 
 value_index=0
 values_total=0
@@ -35,6 +35,7 @@ StopTime=0
 
 version="0"
 build="0"
+user=""
 
 #arrays, indexes, lenghts
 arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
