@@ -50,8 +50,9 @@ def main():
         data.debug=0
 
     #if not on the N900, a acceleration sensor has to be simulated
-    uname=os.uname()
-    if(uname[1]=="Nokia-N900"): data.demo=0	#runs on real N900 hardware
+#    uname=os.uname()
+#    if(uname[1]=="Nokia-N900"): data.demo=0	#runs on real N900 hardware
+    if os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord"): data.demo=0	#runs on real N900 hardware
     else: data.demo=1	#runs on other hardware/OS
 
 
@@ -74,6 +75,19 @@ def main():
 
     StartWindow.UpdateScreenStart()
     StartWindow.show()
+    
+    #get user name for in log files
+    if(data.user==""):
+#            tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+        text = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
+                                                                                             "It will be used in the records file, this makes it easier\n" + \
+                                                                                             "when you want to share your sleep pattern with others.")
+        if(text != ""):
+            data.user=text[0]
+            config.set('main', 'user', str(data.user))    
+        else:
+            pass
+    print "User name:",  data.user
 
     sys.exit(app.exec_())
 
@@ -193,6 +207,12 @@ def StartMeasurement(interval):
     CollectingWindowGraph.show()
     
     print "Start timers (Interval:", interval ,"ms)..."
+    print "Sampling interval:", interval, "ms"
+    print "sample_smoothing:", data.sample_smoothing, "x"
+    print "value_smoothing:", data.value_smoothing, "x"
+    print "=> log interval:", interval*data.value_smoothing, "ms"
+    print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
+    
     app.timer_GetData = QtCore.QTimer()
     QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
     app.timer_GetData.start(interval)
@@ -456,6 +476,7 @@ class frmStartWindow(QtGui.QWidget):
     def UpdateScreenStart(self):
         try:   
             app_path=os.path.dirname(__file__)
+            if(app_path==""): app_path="./"
             print "Application path:",  app_path
             file = open(app_path+"/version", 'r')
             data.version = file.readline()
@@ -496,10 +517,10 @@ class frmCollectingWindow(QtGui.QWidget):
         else:
             self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")
 
-            t=time.mktime(time.localtime())
-            time_difference=t-data.StartTimeSec
-            t=strftime("%H:%M:%S", time.localtime(time_difference))
-            self.ui.lblElapsedTime.setText(t)
+        t=time.mktime(time.localtime())
+        time_difference=t-data.StartTimeSec
+        t=strftime("%H:%M:%S", time.localtime(time_difference))
+        self.ui.lblElapsedTime.setText(t)
             
 
     def UpdateScreenStart(self):
