@@ -26,13 +26,13 @@ def StartLogfile(interval):
     except:
         print "Failed to create logfolder!"
         
-    print "Get IMEI number..."
-    if(data.demo==0):
-        x = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
-        x2=string.split(x, "\"")
-        imei=x2[1]
-        ID=imei[10:]
-    else: ID="00000"    
+#    print "Get IMEI number..."
+#    if(data.demo==0):
+#        x = os.popen('run-standalone.sh dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei').read()
+#        x2=string.split(x, "\"")
+#        imei=x2[1]
+#        ID=imei[10:]
+#    else: ID="00000"    
     
     #open file, write header
     data.StartTime=time.localtime()
@@ -40,11 +40,11 @@ def StartLogfile(interval):
     data.logfilename=data.logfolder+"SleepAnalyser_"+t+".csv"
     data.logfile = open(data.logfilename, 'w')
     print "Created logfile "+data.logfilename
-    t="Date/Time, AccX, AccY, "
-    d=strftime("%d-%b-%Y", data.StartTime)
-    data.logfile.write(t+"IMEI: *"+ID+", SW version: "+data.version+", Date: " + d + \
-            ", Sampling interval: " + str(interval)+" ms, value_smoothing: " + \
-            str(data.sample_smoothing )+"\n") #Print file header
+    t="Time, AccX, AccY, "
+    d=strftime("%d-%m-%Y", data.StartTime)
+    data.logfile.write(t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
+            ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
+            ", value_smoothing: " + str(data.sample_smoothing )+"\n") #Print file header
 
     data.StartTimeSec=time.mktime(data.StartTime)
 
@@ -148,6 +148,7 @@ def LoadConfig():
         data.Ysize = config.getint('main', 'Ysize')
         data.Xscale = config.getint('main', 'Xscale')
         data.Yscale = config.getint('main', 'Yscale')
+        data.user = config.get('main', 'user')
         print "Configuration loaded ("+data.ConfigFile+")"
 #    else:
     except: #use default config
@@ -164,6 +165,7 @@ def LoadConfig():
         config.set('main', 'Ysize', str(data.Ysize))      
         config.set('main', 'Xscale', str(data.Xscale))     
         config.set('main', 'Yscale', str(data.Yscale))      
+        config.set('main', 'user', str(data.user))      
 
     #faster sampling in demo mode
     if(data.debug==1):
@@ -172,10 +174,12 @@ def LoadConfig():
     #print usefull data
     print "SW version:", data.version
 #    print "Sampling interval:", data.sampling, "ms"
-    print "sample_smoothing:", data.sample_smoothing, "x"
-    print "value_smoothing:", data.value_smoothing, "x"
-    print "=> log interval:", data.sampling*data.value_smoothing/1000, "s"
+#    print "sample_smoothing:", data.sample_smoothing, "x"
+#    print "value_smoothing:", data.value_smoothing, "x"
+#    print "=> log interval:", data.sampling*data.value_smoothing/1000, "s"
+#    print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
 #    print "Trigger level:", data.trigger
+    print "Yscale (for graph only):",  data.Yscale
 
     return config
 
@@ -206,28 +210,22 @@ def WriteConfig(config):
 ###########################################################################
 # Read the sensor data x times and smoothen it
 ###########################################################################
-def ReadAccSensor():
-    
-    coords=[0, 0]
-    
-    if(data.demo==0):
-        
+def ReadAccSensor():    
+    coords=[0, 0]    
+    if(data.demo==0):        
         for i in range(data.sample_smoothing):
             f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r' )
             coords_tmp = [int(w) for w in f.readline().split()]
             f.close()
             coords[0]=coords[0] + coords_tmp[0] #X
             coords[1]=coords[1] + coords_tmp[1] #Y
-        
         coords[0]=coords[0] / data.sample_smoothing
         coords[1]=coords[1] / data.sample_smoothing
-        
     else:
         coords[0]=int(random.uniform(-50,50))
         coords[1]=int(random.uniform(-50,50))
 
     print coords[0],  coords[1]
-
     return coords
 
 
@@ -259,6 +257,7 @@ def GetSensorData():
         data.arrDataTemp[0]=0
         data.arrDataTemp[1]=0
 
+        print "smoothened:",  data.arrData[1][data.arrDataIndex],  data.arrData[2][data.arrDataIndex]
         return 1 #added new values to arrData     (interval: sampling*sample_smoothing*value_smoothing)
     else: return 0 #no new data added
 
